@@ -86,7 +86,8 @@ test_that("truncation parameters can be specified in different ways", {
 
 test_that("distributions incompatible with stan models are caught", {
   expect_error(suppressMessages(gt_opts(
-    Gamma(2, 2), default_cdf_cutoff = 0
+    Gamma(2, 2),
+    default_cdf_cutoff = 0
   )), "maximum")
   expect_error(delay_opts(
     Normal(2, 2, max = 10)
