@@ -23,14 +23,16 @@ inc_cases[
 # fit model to example data specifying a weak prior for fraction reported
 # with a secondary case
 inc <- estimate_secondary(inc_cases[1:60],
-  obs = obs_opts(scale = list(mean = 0.2, sd = 0.2), week_effect = FALSE),
+  obs = obs_opts(
+    scale = Normal(mean = 0.2, sd = 0.2, max = 1), week_effect = FALSE
+  ),
   verbose = FALSE
 )
 
 # extract posterior variables of interest
 params <- c(
   "meanlog" = "delay_params[1]", "sdlog" = "delay_params[2]",
-  "scaling" = "frac_obs[1]"
+  "scaling" = "params[1]"
 )
 
 inc_posterior <- inc$posterior[variable %in% params]
@@ -58,7 +60,7 @@ prev <- estimate_secondary(prev_cases[1:100],
   secondary = secondary_opts(type = "prevalence"),
   obs = obs_opts(
     week_effect = FALSE,
-    scale = list(mean = 0.4, sd = 0.1)
+    scale = Normal(mean = 0.4, sd = 0.1)
   ),
   verbose = FALSE
 )
@@ -73,7 +75,7 @@ test_that("estimate_secondary can return values from simulated data and plot
   expect_equal(
     names(inc$predictions),
     c(
-      "date", "primary", "secondary", "mean", "se_mean", "sd",
+      "date", "primary", "secondary", "accumulate", "mean", "se_mean", "sd",
       "lower_90", "lower_50", "lower_20", "median", "upper_20", "upper_50", "upper_90"
     )
   )
@@ -90,7 +92,7 @@ test_that("estimate_secondary successfully returns estimates when passed NA valu
     delays = delay_opts(
       LogNormal(meanlog = 1.8, sdlog = 0.5, max = 30)
     ),
-    obs = obs_opts(scale = list(mean = 0.2, sd = 0.2), week_effect = FALSE),
+    obs = obs_opts(scale = Normal(mean = 0.2, sd = 0.2), week_effect = FALSE),
     verbose = FALSE
   )
   prev_cases_na <- data.table::copy(prev_cases)
@@ -100,7 +102,7 @@ test_that("estimate_secondary successfully returns estimates when passed NA valu
     delays = delay_opts(
       LogNormal(mean = 1.8, sd = 0.5, max = 30)
     ),
-    obs = obs_opts(scale = list(mean = 0.2, sd = 0.2), week_effect = FALSE),
+    obs = obs_opts(scale = Normal(mean = 0.2, sd = 0.2), week_effect = FALSE),
     verbose = FALSE
   )
   expect_true(is.list(inc_na$data))
@@ -113,7 +115,12 @@ test_that("estimate_secondary successfully returns estimates when accumulating t
   secondary_weekly[, secondary := frollsum(secondary, 7)]
   secondary_weekly <- secondary_weekly[seq(7, nrow(secondary_weekly), by = 7)]
   cases_weekly <- merge(
-    cases[, list(date, primary)], secondary_weekly, by = "date", all.x = TRUE
+    cases[, list(date, primary)], secondary_weekly,
+    by = "date", all.x = TRUE
+  )
+  cases_weekly <- fill_missing(
+    cases_weekly,
+    missing_obs = "accumulate", obs_column = "secondary"
   )
   inc_weekly <- estimate_secondary(cases_weekly,
     delays = delay_opts(
@@ -122,7 +129,7 @@ test_that("estimate_secondary successfully returns estimates when accumulating t
       )
     ),
     obs = obs_opts(
-      scale = list(mean = 0.4, sd = 0.05), week_effect = FALSE, na = "accumulate"
+      scale = Normal(mean = 0.4, sd = 0.05), week_effect = FALSE
     ), verbose = FALSE
   )
   expect_true(is.list(inc_weekly$data))
@@ -130,7 +137,7 @@ test_that("estimate_secondary successfully returns estimates when accumulating t
 
 test_that("estimate_secondary works when only estimating scaling", {
   inc <- estimate_secondary(inc_cases[1:60],
-    obs = obs_opts(scale = list(mean = 0.2, sd = 0.2), week_effect = FALSE),
+    obs = obs_opts(scale = Normal(mean = 0.2, sd = 0.2), week_effect = FALSE),
     delay = delay_opts(),
     verbose = FALSE
   )
@@ -147,10 +154,12 @@ test_that("estimate_secondary can recover simulated parameters", {
     tolerance = 0.1
   )
   expect_equal(
-    prev_posterior[, mean], c(1.6, 0.8, 0.3), tolerance = 0.2
+    prev_posterior[, mean], c(1.6, 0.8, 0.3),
+    tolerance = 0.2
   )
   expect_equal(
-    prev_posterior[, median], c(1.6, 0.8, 0.3), tolerance = 0.2
+    prev_posterior[, median], c(1.6, 0.8, 0.3),
+    tolerance = 0.2
   )
 })
 
@@ -159,7 +168,7 @@ test_that("estimate_secondary can recover simulated parameters with the
   skip_on_os("windows")
   output <- capture.output(suppressMessages(suppressWarnings(
     inc_cmdstanr <- estimate_secondary(inc_cases[1:60],
-      obs = obs_opts(scale = list(mean = 0.2, sd = 0.2), week_effect = FALSE),
+      obs = obs_opts(scale = Normal(mean = 0.2, sd = 0.2), week_effect = FALSE),
       verbose = FALSE, stan = stan_opts(backend = "cmdstanr")
     )
   )))
@@ -198,7 +207,8 @@ test_that("forecast_secondary can return values from simulated data when using
   skip_on_os("windows")
   capture.output(suppressMessages(suppressWarnings(
     inc_preds <- forecast_secondary(
-      inc, inc_cases[seq(61, .N)][, value := primary], backend = "cmdstanr"
+      inc, inc_cases[seq(61, .N)][, value := primary],
+      backend = "cmdstanr"
     )
   )))
   expect_equal(names(inc_preds), c("samples", "forecast", "predictions"))
@@ -211,36 +221,59 @@ test_that("estimate_secondary works with weigh_delay_priors = TRUE", {
     max = 30
   )
   inc_weigh <- estimate_secondary(
-    inc_cases[1:60], delays = delay_opts(delays),
-    obs = obs_opts(scale = list(mean = 0.2, sd = 0.2), week_effect = FALSE),
+    inc_cases[1:60],
+    delays = delay_opts(delays),
+    obs = obs_opts(scale = Normal(mean = 0.2, sd = 0.2), week_effect = FALSE),
     weigh_delay_priors = TRUE, verbose = FALSE
   )
   expect_s3_class(inc_weigh, "estimate_secondary")
 })
 
 test_that("estimate_secondary works with filter_leading_zeros set", {
+  ## testing deprecated functionality
+  withr::local_options(lifecycle_verbosity = "quiet")
   modified_data <- inc_cases[1:10, secondary := 0]
-  out <- estimate_secondary(
+  modified_data <- filter_leading_zeros(modified_data, obs_column = "secondary")
+  out <- suppressWarnings(estimate_secondary(
     modified_data,
-    obs = obs_opts(scale = list(mean = 0.2, sd = 0.2),
-    week_effect = FALSE),
-    filter_leading_zeros = TRUE,
+    obs = obs_opts(
+      scale = Normal(mean = 0.2, sd = 0.2),
+      week_effect = FALSE
+    ),
     verbose = FALSE
-  )
+  ))
   expect_s3_class(out, "estimate_secondary")
   expect_named(out, c("predictions", "posterior", "data", "fit"))
-  expect_equal(out$predictions$primary, modified_data$primary[-(1:10)])
+  expect_equal(out$predictions$primary, modified_data$primary)
 })
 
 test_that("estimate_secondary works with zero_threshold set", {
+  ## testing deprecated functionality
+  withr::local_options(lifecycle_verbosity = "quiet")
   modified_data <- inc_cases[sample(1:30, 10), primary := 0]
+  modified_data <- apply_zero_threshold(
+    modified_data,
+    threshold = 10, obs_column = "secondary"
+  )
   out <- estimate_secondary(
     modified_data,
-    obs = obs_opts(scale = list(mean = 0.2, sd = 0.2),
-                   week_effect = FALSE),
-    zero_threshold = 10,
+    obs = obs_opts(
+      scale = Normal(mean = 0.2, sd = 0.2),
+      week_effect = FALSE
+    ),
     verbose = FALSE
   )
   expect_s3_class(out, "estimate_secondary")
   expect_named(out, c("predictions", "posterior", "data", "fit"))
 })
+
+test_that("a warning is thrown when using deprecated functionality", {
+  suppressWarnings(expect_deprecated(estimate_secondary(
+    inc_cases,
+    filter_leading_zeros = TRUE, verbose = FALSE
+  ), "filter_leading_zeros"))
+  suppressWarnings(expect_deprecated(estimate_secondary(
+    inc_cases,
+    zero_threshold = 50, verbose = FALSE
+  ), "zero_threshold"))
+})
