@@ -2,11 +2,8 @@ test_that("gp_opts returns correct default values", {
   gp <- gp_opts()
   expect_equal(gp$basis_prop, 0.2)
   expect_equal(gp$boundary_scale, 1.5)
-  expect_equal(gp$ls_mean, 21)
-  expect_equal(gp$ls_sd, 7)
-  expect_equal(gp$ls_min, 0)
-  expect_equal(gp$ls_max, 60)
-  expect_equal(gp$alpha_sd, 0.05)
+  expect_equal(gp$alpha, Normal(0, 0.01))
+  expect_equal(gp$ls, LogNormal(mean = 21, sd = 7, max = 60))
   expect_equal(gp$kernel, "matern")
   expect_equal(gp$matern_order, 3 / 2)
   expect_equal(gp$w0, 1.0)
